__builtin__.basestring

Module __builtin__ :: Class basestring |
[show private | hide private]
[frames | no frames]

## Type basestring

    object --+
             |
            basestring

Known Subclasses:
  `unicode`

    Type basestring cannot be instantiated; it is the base for str and unicode.

Method Summary
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T...
Inherited from object
| ``__init__`(...)` x.__init__(...) initializes x; see x.__class__.__doc__ for signature...
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name...
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name...
| ``__hash__`(x)` x.__hash__() <==> hash(x)...
| ``__reduce__`(...)` helper for pickle...
| ``__reduce_ex__`(...)` helper for pickle...
| ``__repr__`(x)` x.__repr__() <==> repr(x)...
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value...
| ``__str__`(x)` x.__str__() <==> str(x)...

Method Details

### __new__(T, S, ...)
    T.__new__(S, ...) -> a new object with type S, a subtype of T
    Returns:
        a new object with type S, a subtype of T
Overrides: `__builtin__.object.__new__`

Generated by Epydoc 2.1 on Fri Jan 12 00:04:34 2007 | http://epydoc.sf.net